/*---------------------------------------------------------------------------
*	Filename: linearize_example.c
*	
*	Description:  Handling with acam linearization dll
*
*
*	--------------------------------------------------------------------
*	History:	Revision	Description			Date
*				1.0			Initial Version		24.06.2013
*   ---
*	--------------------------------------------------------------------
*	acam messelectronic Proprietary and Confidential
*	Copyright (c) 2013 by acam messelectronic gmbh
*	All rights reserved
*----------------------------------------------------------------------------*/

#include <stdio.h>
#include <conio.h>
//#include "lib/linearize_r01.h"

#define printPrgHeader	printf("\n--------------------------------------------------------"); \
						printf("\n-------------- PCap02plus Linearization ----------------"); \
						printf("\n--------- (c) acam messelectronic gmbh, 2013 -----------"); \
						printf("\n--------------------------------------------------------\n\n");
 

void __cdecl c_lin_coeff_dut(int C_in[], double z[], double theta[], 
	int C_fpp, int C_int_fpp, int z_fpp, int inverse, 
	double cc[], int cc_fpp[], int ccx[], double cci[], 
	double error_vs_z[], int cn_div[], int cn_shift[], 
	int n_samples, int n_cc, int n_cn_div, int n_cn_shift);			

void __cdecl C_2p_nominal(double z[], double theta[], double cc[], 
	int C_fpp, int C_out_hex[], double C_out[], int n_samples, 
	int n_cc);	
	
/* --- main() --- */
int main ( int argc, char *argv[] )
{
	printPrgHeader 
	int i;
	
	/* ----- Parameter for c_lin_coeff_dut ----- */
	int 	C_in[] 		= { 0x5353F7, 0x523D70, 0x51374B, 0x504189, 0x4F5C28, 0x4E76C8, 0x4D9168, 0x4CBC6A, 0x4C5A1C, 0x53126E, 0x51EB85, 0x50E560, 0x4FDF3B, 0x4EF9DB, 0x4E147A, 0x4D1EB8, 0x4C49BA, 0x4BE76C, 0x529FBE, 0x5178D4, 0x50624D, 0x4F4BC6, 0x4E5604, 0x4D6041, 0x4C6A7E, 0x4B851E, 0x4B126E };
	double	theta [] 	= { 15.6, 15.6, 15.6, 15.6, 15.6, 15.6, 15.6, 15.6, 15.6, 25.1, 25.1, 25.1, 25.1, 25.1, 25.1, 25.1, 25.1, 25.1, 39.7, 39.7, 39.7, 39.7, 39.7, 39.7, 39.7, 39.7, 39.7 };
	double	z [] 		= { 0.208, 0.309, 0.408, 0.507, 0.606, 0.704, 0.803, 0.901, 0.945, 0.208, 0.309, 0.408, 0.507, 0.606, 0.704, 0.803, 0.901, 0.945, 0.208, 0.309, 0.408, 0.507, 0.606,  0.704, 0.803, 0.901, 0.945 };	
	int		n_samples 	= sizeof(C_in) / sizeof(C_in[0]);
	int		n_cc		= 12;
	int		n_cn_div 	= 9 ;
	int		n_cn_shift 	= 3 ;
	int		C_fpp 		= 22;
	int		C_int_fpp	= 26;
	int		z_fpp		= 8 ;
	int		inverse 	= 1 ; //LVBoolean inverse

	/* Outputs*/
	double	cc[n_cc];
	int 	cc_fpp[n_cc];
	int 	ccx[n_cc];
	double 	cci[n_cc];
	int 	cn_div[n_cn_div];
	int 	cn_shift[n_cn_shift];
	double	error_vs_z[n_samples];
	/* ----------------------------------------- */

	/* ------ Parameter for c_2p_nominal ------- */
	double z_nominal[] 		= { 22.8, 73.6 };
	double theta_nominal[]	= { 15.4, 39.7 };
	int n_samples_2P		= sizeof(z_nominal) / sizeof(z_nominal[0]);		

	/* Outputs*/
	int 	C_out_hex[n_samples_2P]	;
	double 	C_out[n_samples_2P]		;
	/* ----------------------------------------- */
	
	/* ----------------- Start ----------------- */
	c_lin_coeff_dut (	C_in, z, theta, C_fpp, C_int_fpp, z_fpp,  inverse,	// input
						cc, cc_fpp, ccx, cci, error_vs_z, cn_div, cn_shift,	// output
						n_samples, n_cc, n_cn_div, n_cn_shift);				// size of arrays (input)
						
	printf("Coefficients for single devices -- c_lin_coeff_dut\n");
	printf("Calibration values cc (ascending / [0..11])\n");
	for ( i=0; i<=n_cc/4-1; i++ )
	{
		printf("k0%d %f\tk1%d %f\tk2%d %f\tk3%d %f\n", i, cc[i*4+0], i, cc[i*4+1], i, cc[i*4+2], i, cc[i*4+3]);
	}	

	printf("\ncc_fpp (ascending / [0..11])\n");
	for ( i=0; i<=n_cc/4-1; i++ )
	{
		printf("#%d %d\t#%d %d\t#%d %d\t#%d %d\n", i*4+0, cc_fpp[i*4+0], i*4+1, cc_fpp[i*4+1], i*4+2, cc_fpp[i*4+2], i*4+3, cc_fpp[i*4+3]);
	}		
	
	printf("\ncn_div (ascending / [0..8])\n");
	for ( i=0; i<=n_cn_div/3-1; i++ )
	{
		printf("#%d %d\t#%d %d\t#%d %d\n", i*3+0, cn_div[i*3+0], i*3+1, cn_div[i*3+1], i*3+2, cn_div[i*3+2]);
	}		

	C_2p_nominal (	z_nominal, theta_nominal, cci, C_fpp,	// input
					C_out_hex, C_out,						// output
					n_samples_2P, n_cc);					// size of arrays (input)

	printf("\nNominal value for 2-point calibration -- c_2p_nominal\n");
	for ( i=0; i<=n_samples_2P-1; i++ )
	{
		printf("#%d: Z: %f, theta: %f, C_out: %f, C_out_hex %x\n", i, z_nominal[i], theta_nominal[i], C_out[i], C_out_hex[i]);
	}		
	
	printf("\nPress any key to continue");
	getch();
	
	return 0;	/* return value main() */
	
} // EOF

